﻿using Syncfusion.SfDataGrid.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Xamarin.Forms;

namespace XamarinForms
{
    public class App : Application
    {
        SfDataGrid dataGrid;
        ViewModel viewModel;
        public App()
        {
            dataGrid = new SfDataGrid();
            viewModel = new ViewModel();
            dataGrid.AutoGenerateColumns = false;
            dataGrid.ItemsSource = viewModel.OrdersInfo;
            dataGrid.ColumnSizer = ColumnSizer.Star;
            dataGrid.AllowDraggingRow = true;

            dataGrid.CellRenderers.Remove("TextView");
            dataGrid.CellRenderers.Add("TextView", new GridCellTextViewRendererExt());

            GridTextColumn orderIDColumn = new GridTextColumn();
            orderIDColumn.MappingName = "OrderID";
            orderIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(orderIDColumn);
          
            GridTextColumn EmpIDColumn = new GridTextColumn();
            EmpIDColumn.MappingName = "EmployeeID";
            EmpIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(EmpIDColumn);
           
            GridTextColumn IsBoldColumn = new GridTextColumn();
            IsBoldColumn.MappingName = "IsBold";
            IsBoldColumn.LoadUIView = true;
            dataGrid.Columns.Add(IsBoldColumn);

            GridTextColumn CustomerIDColumn = new GridTextColumn();
            CustomerIDColumn.MappingName = "CustomerID";
            CustomerIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(CustomerIDColumn);

            GridTextColumn FirstNameColumn = new GridTextColumn();
            FirstNameColumn.MappingName = "FirstName";
            FirstNameColumn.LoadUIView = true;
            dataGrid.Columns.Add(FirstNameColumn);

            GridTextColumn GenderColumn = new GridTextColumn();
            GenderColumn.MappingName = "Gender";
            GenderColumn.LoadUIView = true;
            dataGrid.Columns.Add(GenderColumn);
            // The root page of your application
            MainPage = new ContentPage() { Content = dataGrid };
            //MainPage = new SfDataPage();
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }
    }

    public class StyleConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            int _value = (int)value;
            if (_value % 2 == 0)
                return Color.Green;
            return Color.Red;
        }
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    public class GridCellTextViewRendererExt : GridCellTextViewRenderer
    {
        public GridCellTextViewRendererExt()
        {

        }

        public override void OnInitializeDisplayView(DataColumnBase dataColumn, SfLabel view)
        {
            base.OnInitializeDisplayView(dataColumn, view);
            if ((dataColumn.RowData as OrderInfo).IsBold == true)
            {
                view.TextColor = Color.Red;
            }
            else {
                view.TextColor = Color.Green;
            }
        }

        //protected override void OnUpdateCellValue(DataColumnBase dataColumn)
        //{
        //    base.OnUpdateCellValue(dataColumn);
        //    if ((dataColumn as IElement).Element != null)
        //    {
        //        var view = (((dataColumn as IElement).Element as ContentView).Content as SfLabel);
        //        if (view != null)
        //        {
        //            if ((dataColumn.RowData as OrderInfo).IsBold == true)
        //            {
        //                view.FontAttributes = FontAttributes.Bold;
        //                view.TextColor = Color.Red;
        //            }
        //            else {
        //                view.FontAttributes = FontAttributes.None;
        //                view.TextColor = Color.Green;
        //            }
        //        }
        //    }
        //}

        protected override void OnUpdateCellStyle(DataColumnBase dataColumn)
        {
            base.OnUpdateCellStyle(dataColumn);
            if ((dataColumn as IElement).Element != null)
            {
                var view = (((dataColumn as IElement).Element as ContentView).Content as SfLabel);
                if (view != null)
                {
                    if ((dataColumn.RowData as OrderInfo).IsBold == true)
                    {
                        view.FontAttributes = FontAttributes.Bold;
                        view.TextColor = Color.Red;
                    }
                    else {
                        view.FontAttributes = FontAttributes.None;
                        view.TextColor = Color.Green;
                    }
                }
            }
        }

    }
}
